from rest_framework import viewsets, mixins, status
from rest_framework.permissions import IsAuthenticated
from rest_framework.response import Response
from django.db.models import Q

from courses.models import Course
from .models import Class
from courses.classes.serializers import (
    BasicClassSerializer,
    ClassSerializer,
)


class BasicClassViewSet(viewsets.ReadOnlyModelViewSet):

    queryset = Class.objects.all().order_by('-name')
    serializer_class = BasicClassSerializer
    filter_fields = ['course']
    permission_classes = [IsAuthenticated]

    def get_queryset(self):
        queryset = super().get_queryset()
        if not (self.request.user.is_staff or self.request.user.is_superuser):

            queryset = queryset.filter(
                Q(course__professors=self.request.user, course__course_professors__role__in=['coordinator', 'assistant']) |
                Q(assistants=self.request.user)
            ).distinct()

        queryset = queryset.prefetch_related('assistants')

        return queryset


class ClassViewSet(BasicClassViewSet, viewsets.ModelViewSet):

    serializer_class = ClassSerializer

    def get_queryset(self):
        queryset = super().get_queryset()

        queryset = queryset.prefetch_related(
            'assistants',
            'students',
            'course__course_students',
        )

        return queryset
